CustomButtons class

Inheritance

Constructors

CustomButtons({Key? key, required String actionIcon, bool miniButton = false, ValueNotifier<bool>? isLoading, bool fillButton = false, required IconPosition position, required String buttonText, Widget? leading, Widget? trailing, TextStyle? textStyle, int? borderRadius, Color? buttonColor})
const
CustomButtons.buttonWithLeading({required String actionIcon, bool? borderedButton, ValueNotifier<bool>? isLoading, bool? fillButton, required IconPosition position, required String buttonText, Widget? leading, TextStyle? textStyle, int? borderRadius})
factory
CustomButtons.buttonWithTrailing({required String actionIcon, bool? borderedButton, ValueNotifier<bool>? isLoading, bool? fillButton, required IconPosition position, required String buttonText, Widget? trailing, TextStyle? textStyle, int? borderRadius})
factory
CustomButtons.mini({required String actionIcon, bool? borderedButton, ValueNotifier<bool>? isLoading, bool? fillButton, required IconPosition position, required String buttonText, Widget? leading, Widget? trailing, TextStyle? textStyle, int? borderRadius})
factory
CustomButtons.regular({required String actionIcon, bool? borderedButton, ValueNotifier<bool>? isLoading, bool? fillButton, required IconPosition position, required String buttonText, Widget? leading, Widget? trailing, TextStyle? textStyle, int? borderRadius})
factory

Properties

actionIcon → String
final
borderRadius → int?
final
buttonColor → Color?
final
buttonText → String
final
fillButton → bool
final
hashCode → int
The hash code for this object.
no setterinherited
isLoading → ValueNotifier<bool>?
final
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
leading → Widget?
final
miniButton → bool
final
position → IconPosition
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
textStyle → TextStyle?
final
trailing → Widget?
final

Methods

createElement() → StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() → State<CustomButtons>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited